API Reference
=============

.. currentmodule:: pytantan

.. automodule:: pytantan


Functions
---------

.. autofunction:: pytantan.mask_repeats

.. autofunction:: pytantan.default_scoring_matrix



Classes
-------

.. toctree::
   :hidden:

   Alphabet <alphabet>
   LikelihoodMatrix <likelihood_matrix>
   RepeatFinder <repeat_finder>


.. only:: html

    .. autosummary::
        :nosignatures:

        pytantan.Alphabet
        pytantan.LikelihoodMatrix
        pytantan.RepeatFinder
